@@ -26,8 +26,10 @@ def respect_language(language):
     if language:
         prev = translation.get_language()
         translation.activate(language)
-        yield
-        translation.activate(prev)
+        try:
+            yield
+        finally:
+            translation.activate(prev)
     else:
         yield
 
