@@ -16,9 +16,9 @@ beat = celerybeat.BeatCommand(app=app)
 class Command(CeleryCommand):
     """Run the celery periodic task scheduler."""
     options = (CeleryCommand.options
-             + beat.get_options()
-             + beat.preload_options)
-    help = 'Runs the Celery periodic task scheduler'
+               + beat.get_options()
+               + beat.preload_options)
+    help = 'Old alias to the "celery beat" command.'
 
     def handle(self, *args, **options):
         beat.run(*args, **options)
