@@ -15,11 +15,11 @@ worker = celeryd.WorkerCommand(app=app)
 
 class Command(CeleryCommand):
     """Run the celery daemon."""
-    help = 'Runs a Celery worker node.'
+    help = 'Old alias to the "celery worker" command.'
     requires_model_validation = True
     options = (CeleryCommand.options
-             + worker.get_options()
-             + worker.preload_options)
+               + worker.get_options()
+               + worker.preload_options)
 
     def handle(self, *args, **options):
         worker.run(*args, **options)
