@@ -13,16 +13,16 @@ class TestDjangoLoader(unittest.TestCase):
 
     def test_get_loader_cls(self):
 
-        self.assertEqual(loaders.get_loader_cls("django"),
-                          self.loader.__class__)
+        self.assertEqual(loaders.get_loader_cls('django'),
+                         self.loader.__class__)
         # Execute cached branch.
-        self.assertEqual(loaders.get_loader_cls("django"),
-                          self.loader.__class__)
+        self.assertEqual(loaders.get_loader_cls('django'),
+                         self.loader.__class__)
 
     def test_on_worker_init(self):
         from django.conf import settings
-        old_imports = getattr(settings, "CELERY_IMPORTS", None)
-        settings.CELERY_IMPORTS = ("xxx.does.not.exist", )
+        old_imports = getattr(settings, 'CELERY_IMPORTS', ())
+        settings.CELERY_IMPORTS = ('xxx.does.not.exist', )
         try:
             self.assertRaises(ImportError, self.loader.import_default_modules)
         finally:
@@ -36,8 +36,9 @@ class TestDjangoLoader(unittest.TestCase):
             djloaders._RACE_PROTECTION = False
 
     def test_find_related_module_no_path(self):
-        self.assertFalse(djloaders.find_related_module("sys", "tasks"))
+        self.assertFalse(djloaders.find_related_module('sys', 'tasks'))
 
     def test_find_related_module_no_related(self):
-        self.assertFalse(djloaders.find_related_module("someapp",
-                                                       "frobulators"))
+        self.assertFalse(
+            djloaders.find_related_module('someapp', 'frobulators'),
+        )
